"""
    Set up the sdc_helpers package
"""
from setuptools import setup


def get_required(file_name):
    """
        Get Required Filename during setup
    """
    with open(file_name):
        return file_name.read().splitlines()


setup(
    name='sdc-helpers',
    packages=['sdc_helpers', 'sdc_helpers.models'],
    install_requires=['sqlalchemy', 'pymysql', 'redis', 'boto3', 'requests'],
    description='Global SDC Helpers package',
    version='1.5.3',
    url='https://github.com/RingierIMU/sdc-global-all-helpers',
    author='Ringier South Africa',
    author_email='tools@ringier.co.za',
    keywords=['pip', 'helpers'],
    download_url='https://github.com/RingierIMU/sdc-global-all-helpers/archive/v1.5.3.zip'
)



"""
   SDC decorators module
"""
from functools import wraps
from sqlalchemy.exc import SQLAlchemyError


def query_exception_handler(exceptions: tuple = (SQLAlchemyError, )):
    """
        Decorator - handling SqlAlchemy specific exceptions

        args:
            exceptions (Exception): List of exceptions to catch

        return:
            Wrapped function's response
    """
    def query_exception_decorator(function):
        @wraps(function)
        def func_with_exceptions(*args, **kwargs):
            """
                Wrapper function to decorate function with
            """
            try:
                return function(*args, **kwargs)
            except exceptions as ex:
                if ex.__dict__.get('orig') is not None:
                    ex.__dict__['orig'] = 'Server Error: {ex}'.format(
                        ex=str(ex.__dict__['orig'])
                    )
                    raise ex

                raise Exception(
                    'Server Error: {ex}'.format(
                        ex=str(ex)
                    )
                )

        return func_with_exceptions

    return query_exception_decorator
